pub struct ShellExecutor { /* private fields */ }Expand description
Executes tools by running shell commands through a VirtualExecutor.
The tool arguments should contain a command field with the shell command to run.
On native platforms, use NativeExecutor.
In WASM / tests, inject a MockExecutor or
NoopExecutor.
Implementations